package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@(!`0D```````````(`/@`!````X!U```````!``````````""W````
M`````````$``.``(`$``&P`:``8````%````0`````````!``$```````$``
M0```````P`$```````#``0````````@``````````P````0``````@``````
M```"0`````````)````````5`````````!4``````````0`````````!````
M!0````````````````!``````````$```````,RI````````S*D`````````
M`"````````$````&`````+``````````L&````````"P8```````=`0`````
M```H"0``````````(````````@````8````HL````````"BP8```````*+!@
M```````0`@```````!`"````````"``````````$````!````!@"````````
M&`)````````8`D```````#``````````,``````````$`````````%#E=&0$
M````_*4```````#\I4```````/RE0```````M`````````"T``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````"``````````O;&EB97AE8R]L9"UE;&8N<V\N,0`````(````
M!`````$```!&<F5E0E-$`/A-#P`(````!`````(```!&<F5E0E-$``````!#
M````6P`````````'`````````#D````\``````````````!,`````````#(`
M``!/````(@```",````8`````````#L```!6`````````#,````]````````
M``````!'````!0```$D````6````#@```"T```!!````2@```!4`````````
M4P`````````@````+```````````````$````"D`````````.``````````N
M````5P```!D````>````5`````````!&````2P``````````````50```"@`
M```=````+P`````````Z````4``````````V`````0```$`````J````*P``
M`$(```````````````````````````````````````````````,`````````
M`````$@`````````````````````````````````````````!`````P`````
M``````````````!2````````````````````"0`````````<````"@```$X`
M````````0P```````````````@```#X````7````&P````T````3````$@``
M`"$````1````)P```!0`````````#P``````````````"````!H````T````
M'P```#\`````````10`````````Q````6````%$````&`````````"8```!9
M``````````````!-````````````````````"P```"0`````````,```````
M``!$`````````#4``````````````````````````````#<`````````6@``
M`"4`````````$0```#X````$````"````"`,```%0`2`*`!``)"&`8C"`0$@
M20`$&HB",$FZ``8(/@```$````!#````1@```$<```!-````3@```$\```!1
M````4@````````!3````50```%<```!8`````````%H```"\4':>>_!*:V[%
MWQ_.WD<M:W^:?"[%F[;49-1\(?_D#MEQ6!SB1\8!L@&+;\+E/RRZXY)\\MO3
M'?NA;&"'^9R!9Z_,9D)%U>R)!W#3R=6R<3-BV^U6I)N6I]VC:WZIG)OG%0.#
MX:<""@J*$%>CX/M)(6)D!P```````````````````````````````*0!```2
M``````````````"K%`````````8!```2```````````````8`````````,P#
M```2```````````````3`````````(T!```2``````````````"B(```````
M`"<"```2```````````````1`````````.X"```2``````````````#!````
M``````T````@`````````````````````````$T!```2``````````````"#
M`P```````*X````2```````````````I`0```````#T!```2````````````
M```[`````````"\!```2``````````````!#`0````````0#```2````````
M```````I`````````+P"```2``````````````"8`````````!,#```2````
M```````````1``````````L#```2``````````````!3``````````<"```2
M```````````````1`````````*L!```2``````````````#"`0```````#<"
M```2```````````````&`````````#`"```2``````````````!&````````
M`%`"```2``````````````#,`````````.8"```2``````````````"$````
M`````&`"```2```````````````+`````````%P````2``````````````"!
M`````````!H"```2``````````````!.`````````"`"```2````````````
M``#;`````````&P"```2```````````````.`````````.H````2````````
M``````!V`````````(H````2``````````````"#"````````/\!```2````
M```````````D``````````8"```2```````````````1`````````$$"```2
M```````````````1`````````&8"```2```````````````1`````````*\"
M```2```````````````1`````````($"```2```````````````T````````
M`,X````2``````````````!N`0```````&\!```2``````````````!P`0``
M`````"$````2``````````````"H`````````&$!```2```````````````0
M%@```````#`````2``````````````!/`````````/T"```2````````````
M```1`````````)`"```2``````````````!)`````````,,"```2````````
M```````0`````````!`!```2``````````````!A`0```````$@"```2````
M``````````#S&0```````*<"```2```````````````+`````````)\"```2
M``````````````!5``````````P"```2``````````````!*`````````)D`
M```2``````````````":`````````!,"```2``````````````!Z````````
M`+4"```2```````````````1`````````'$"```2``````````````!4````
M`````)@!```2``````````````!```````````8#```2```````````````Q
M``````````L!```2``````````````!<`P```````%8!```2````````````
M``!>`````````&H````2``````````````"+`````````%@"```2````````
M``````!*`````````'@"```2```````````````1`````````)@"```2````
M``````````!^`````````(D"```2```````````````Y`````````+P````2
M``````````````"0"````````/0!```1`!<`2+1@```````(`````````'T!
M```2````?!M```````"E`0```````-4#```2``T`,$)````````I`0``````
M`.D#```2``T`<#1````````M#0```````"P$```2``T`P$E````````7`P``
M`````%8#```2``T`,"%````````*`````````'0#```2``T`L$1````````/
M!0````````@$```2``T`0"%````````Z`@```````"$#```0`/'_=+1@````
M`````````````&<#```2``T`H"5````````V`````````(H#```2``T``#)`
M``````"Y`````````.$#```2``T`,"!````````G`````````"T#```0`/'_
M*+E@`````````````````+8!```1`!@`X+1@```````3`````````/8#```2
M``T`X#)```````",`0```````'D````2````C!M```````!A`````````*X#
M```2``T`X"5```````#)`````````!H#```0`/'_=+1@````````````````
M`!4$```1`!<`:+1@```````(`````````!P!```2````3!I```````!A````
M`````"8#```2``T`X!U```````!V`0```````/L````1`!@`@+1@```````$
M`````````%0````1`!@`(+E@```````(`````````+H#```2``T`P#)`````
M```?`````````/,"```1`!@`^+1@```````(`````````)@#```2``T`8"!`
M``````#)`````````-T````1`!@`T+1@```````!`````````!\$```2``T`
ML"9```````!/"P```````-0"```1`!@`D+1@``````!```````````!L:6)T
M:'(N<V\N,P!?2G9?4F5G:7-T97)#;&%S<V5S`'!T:')E861?871F;W)K`'!T
M:')E861?9V5T<W!E8VEF:6,`;&EB<&5R;"YS;RXU+C(P`&5N=FER;VX`4&5R
M;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E
M<FQ?8V]N<W1R=6-T`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI
M9G0`4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD
M=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R
M;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R
M;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C
M=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E
M<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI
M8FTN<V\N-0!L:6)C<GEP="YS;RXU`&QI8G5T:6PN<V\N.0!L:6)C+G-O+C<`
M7U]P<F]G;F%M90!M96UC:'(`;'-T870`;65M8W!Y`'-T<G-T<@!L<V5E:P!S
M=')L96X`<F5A9&QI;FL`<W1R9'5P`%]I;FET7W1L<P!G971U:60`<F5A;&QO
M8P!F<')I;G1F`&UE;6UO=F4`8VQO<V4`;6MD:7(`<F5A9`!M96US970`8VQO
M<V5D:7(`<W1R;F-M<`!S=')C:'(`<W1R;F-P>0!S=')C;7``;W!E;F1I<@!?
M7V5R<F]R`')M9&ER`&=E='!I9`!S=')T;VL`7U]S=&%C:U]C:&M?9F%I;`!?
M7W-T86-K7V-H:U]G=6%R9`!S<')I;G1F`&]P96X`7U]S=&1E<G)P`&%C8V5S
M<P!A=&5X:70`<F5A9&1I<@!U;FQI;FL`7V5D871A`%]?8G-S7W-T87)T`%]E
M;F0`+W5S<B]L;V-A;"]L:6(O<&5R;#4O-2XR,"]M86-H+T-/4D4`<&%R7V-U
M<G)E;G1?97AE8P!P87)?8F%S96YA;64`6%-?26YT97)N86QS7U!!4E]"3T]4
M`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D:7)N
M86UE`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`'AS
M7VEN:70`<&%R7VUK=&UP9&ER`'!A<E]S971U<%]L:6)P871H`'!A<E]F:6YD
M<')O9P!M>5]P87)?<&P`<&%R7VEN:71?96YV`&UA:6X`1D)31%\Q+C`````"
M`````@````(``@```````````````@`"``(``@`"`````@`"``(``@`"````
M`@`"``(```````(``@`"``(``@`"```````#`````P`"``(``@````(``@`"
M``(````"``(``@````(``@```````@`"``(``@````$````!``$``0`!``$`
M`0`!``$``0`!``$````!`````0`!``$````!`````0`!``(``0````$``@`!
M``$``0```!`````@````L"AZ!P```P`Q!`````````$``0#J`0``$```````
M``"P*'H'```"`#$$````````@+1@```````%````4P``````````````D+1@
M```````%````6@``````````````T+1@```````%````6```````````````
MX+1@```````%````2P``````````````^+1@```````%````5@``````````
M````4+)@```````'`````0``````````````6+)@```````'`````@``````
M````````8+)@```````'`````P``````````````:+)@```````'````!```
M````````````<+)@```````'````!0``````````````>+)@```````'````
M!@``````````````@+)@```````'````40``````````````B+)@```````'
M````"```````````````D+)@```````'````"0``````````````F+)@````
M```'````"@``````````````H+)@```````'````"P``````````````J+)@
M```````'````#```````````````L+)@```````'````#0``````````````
MN+)@```````'````#@``````````````P+)@```````'````#P``````````
M````R+)@```````'````$```````````````T+)@```````'````$0``````
M````````V+)@```````'````$@``````````````X+)@```````'````$P``
M````````````Z+)@```````'````%```````````````\+)@```````'````
M%0``````````````^+)@```````'````%@```````````````+-@```````'
M````%P``````````````"+-@```````'````&```````````````$+-@````
M```'````&0``````````````&+-@```````'````/P``````````````(+-@
M```````'````30``````````````*+-@```````'````&@``````````````
M,+-@```````'````&P``````````````.+-@```````'````'```````````
M````0+-@```````'````'0``````````````2+-@```````'````'@``````
M````````4+-@```````'````'P``````````````6+-@```````'````(```
M````````````8+-@```````'````(0``````````````:+-@```````'````
M(@``````````````<+-@```````'````(P``````````````>+-@```````'
M````)```````````````@+-@```````'````)0``````````````B+-@````
M```'````)@``````````````D+-@```````'````)P``````````````F+-@
M```````'````*```````````````H+-@```````'````*0``````````````
MJ+-@```````'````*@``````````````L+-@```````'````*P``````````
M````N+-@```````'````+```````````````P+-@```````'````+0``````
M````````R+-@```````'````+@``````````````T+-@```````'````+P``
M````````````V+-@```````'````,```````````````X+-@```````'````
M,0``````````````Z+-@```````'````,@``````````````\+-@```````'
M````,P``````````````^+-@```````'````-````````````````+1@````
M```'````-0``````````````"+1@```````'````-@``````````````$+1@
M```````'````-P``````````````&+1@```````'````.```````````````
M(+1@```````'````.0``````````````*+1@```````'````.@``````````
M````,+1@```````'````.P``````````````.+1@```````'````/```````
M````````0+1@```````'````/0``````````````2(/L".@O!@``Z,I*``!(
M@\0(PP#_-5Z8(`#_)6"8(``/'T``_R5>F"``:`````#IX/____\E5I@@`&@!
M````Z=#_____)4Z8(`!H`@```.G`_____R5&F"``:`,```#IL/____\E/I@@
M`&@$````Z:#_____)3:8(`!H!0```.F0_____R4NF"``:`8```#I@/____\E
M)I@@`&@'````Z7#_____)1Z8(`!H"````.E@_____R46F"``:`D```#I4/__
M__\E#I@@`&@*````Z4#_____)0:8(`!H"P```.DP_____R7^ER``:`P```#I
M(/____\E]I<@`&@-````Z1#_____)>Z7(`!H#@```.D`_____R7FER``:`\`
M``#I\/[___\EWI<@`&@0````Z>#^____)=:7(`!H$0```.G0_O___R7.ER``
M:!(```#IP/[___\EQI<@`&@3````Z;#^____);Z7(`!H%````.F@_O___R6V
MER``:!4```#ID/[___\EKI<@`&@6````Z8#^____)::7(`!H%P```.EP_O__
M_R6>ER``:!@```#I8/[___\EEI<@`&@9````Z5#^____)8Z7(`!H&@```.E`
M_O___R6&ER``:!L```#I,/[___\E?I<@`&@<````Z2#^____)7:7(`!H'0``
M`.D0_O___R5NER``:!X```#I`/[___\E9I<@`&@?````Z?#]____)5Z7(`!H
M(````.G@_?___R56ER``:"$```#IT/W___\E3I<@`&@B````Z<#]____)4:7
M(`!H(P```.FP_?___R4^ER``:"0```#IH/W___\E-I<@`&@E````Z9#]____
M)2Z7(`!H)@```.F`_?___R4FER``:"<```#I</W___\E'I<@`&@H````Z6#]
M____)1:7(`!H*0```.E0_?___R4.ER``:"H```#I0/W___\E!I<@`&@K````
MZ3#]____)?Z6(`!H+````.D@_?___R7VEB``:"T```#I$/W___\E[I8@`&@N
M````Z0#]____)>:6(`!H+P```.GP_/___R7>EB``:#````#IX/S___\EUI8@
M`&@Q````Z=#\____)<Z6(`!H,@```.G`_/___R7&EB``:#,```#IL/S___\E
MOI8@`&@T````Z:#\____);:6(`!H-0```.F0_/___R6NEB``:#8```#I@/S_
M__\EII8@`&@W````Z7#\____)9Z6(`!H.````.E@_/___R66EB``:#D```#I
M4/S___\ECI8@`&@Z````Z4#\____)8:6(`!H.P```.DP_/___R5^EB``:#P`
M``#I(/S___\E=I8@`&@]````Z1#\____)6Z6(`!H/@```.D`_/__`````%5(
MB>5!5T%6055!5%-028G^38L^26/'38ULQA!(@ST<FR```'4'3(DM$YL@`$F#
MQ@A%A?]^)4F+!DB%P'4%ZQM(_\!(B04>EB``ZP1(_\"0B@B`^2]TZ83)=?&X
M*+!@`$B%P'0*2(GWZ$_\___K!>BH_/__N"BP8`!(A<`/A=\```"_8!]``.@P
M_/__13'DN`"P8`"Y`+!@`$@IP4B)R$C!^#](P>@]2`'(2,'X`W1!N`"P8`"Y
M`+!@`$@IP4B)RTC!^S](P>L]2`'+2,'[`Y!*BP3E`+!@`$B#^`)R"T2)_TR)
M]DR)ZO_02?_$23G<<M_H\OK__S';N`"P8`"Y`+!@`$@IP4B)R$C!^#](P>@]
M2`'(2,'X`W1(N`"P8`"Y`+!@`$@IP4F)S$G!_#])P>P]20',2<'\`P\?A```
M````2(L$W0"P8`!(@_@"<@M$B?],B?9,B>K_T$C_PTPYXW+?1(G_3(GV3(GJ
MZ'$J``")Q^CV_?__9BX/'X0``````%5(B>534+@`L&``N0"P8`!(*<%(B<M(
MP?L_2,'K/4@!RTC!^P-T(68/'X0``````$B+!-WXKV``2/_+2(/X`78"_]!(
MA=MUZ$B#Q`A;7>DE10``D)"0D)"0D)"0D)"0D%5(B>6*!9:4(`"$P'0/ZR-(
M@\$(2(D-?90@`/_02(L-=)0@`$B+`4B%P'7DQ@5ME"```5W#9F8N#Q^$````
M``!52(GE2(,]%)`@``!T$K@`````2(7`=`B_(+!@`%W_X%W#D)"0D)"0D)"0
MD)"0D)!52(GEBSU&E"``Z"W\__^^J&5``+I\&T``N3!E0`!(B<==Z17]__]F
M#Q^$``````!52(GE05=!5E-(@>PH"```2(L%&90@`$B)1>#HG/S__XG"13'V
M2(V]T/O__[Y`HT``N>FE0``QP.B/^O__A<!X94B-O=#[__](C;7`]___N@`$
M``#H<_G__TB)PT4Q]H7;>$-(P>,@2+\``````0```$@!WTC!_R#H#_G__TF)
MQT4Q]DV%_W0>2,'[($B-M<#W__],B?](B=KH[OO__T'&!!\`38G^2(L%@Y,@
M`$@[1>!U$4R)\$B!Q"@(``!;05Y!7UW#Z'/[__\/'X``````54B)Y5WI)O__
M_V8/'T0``%5(B>5!5T%6055!5%-(@>P8!```2(FUR/O__TF)_DB+!2N3(`!(
MB4703(LEL)<@`$4Q[4V%Y+A,HT``=0;K8)!(_\"*"(3)=`6`^3UU\DF+'"1%
M,>U(A=MT1;E,HT``*<A,8_A)@\0(13'M#Q]$``"^3*-``$B)WTR)^NA<^O__
MA<!U!T*`/#L]=`])BQPD28/$"$B%VW78ZP5-C6P?`;XO````3(GWZ-#[__](
MA<`/A3`!``!,B??H;_G__TF)Q[[WI4``2(N]R/O__^B;^/__2(7`#X0+`0``
M0?_'3(VET/O__V9F9BX/'X0``````(`X`+OOI4``=`-(B<--A>UT$TR)[TB)
MWNA?^___A<`/A+L```!(B=_H#_G__XU(_TACT8`\$R]U+4@!VHUP_DAC]D@!
MWF9F+@\?A```````Q@(`_\E(8]%(`=K_R(`^+TB-=O]TZD0!^#T`!```#XV!
M````OH6D0`"Y5J1``#'`3(GG2(G:38GPZ&[X__^+/;R1(`#HH_G__TB-L)@!
M``!,B>?H!/C__X7`=32+/9Z1(`#HA?G__P^W@*`!```E`/```&8]`(!U%[X!
M````3(GGZ';Y__^%P'1/9@\?1```,?^^]Z5``.B0]___2(7`#X4+____OU6C
M0`!,B?;H3@```$B+!5>1(`!(.T70=15,B?!(@<08!```6T%<05U!7D%?7</H
M0_G__TB-G=#[__^_5:-``$B)WN@3````2(G?Z)?W__])B<;KN&8/'T0``%5(
MB>5!5T%6055!5%-(@^P828GT28G_08`\)#UU`TG_Q$R)Y^C#]___2(E%R$V%
M_TR+-6F5(`!T!4V%]G4@28L&13'M2(7`#X2+````13'M2X-\[@@`38UM`77T
MZWI,B?CK$&9F9F8N#Q^$``````!(_\"*"(3)=`6`^3UU\DF+#D4Q[4B%R71/
M1"GX3(E]T$ACV$F)STB)3<!-B?4/'P!,B?](BW702(G:Z.WW__^%P'4+08`\
M'ST/A!0!``!-BWT(28/%"$V%_W753(M]T$B+1<#I:?___X`]N90@``%U)T&-
M10)(8_!(P>8#3(GWZ$CX__])B<9-A?9,B36?E"``=43I"0$``,8%B90@``%!
MC44"2&/X2,'G`^A-]?__2(G#2(7;#X3F````26/52,'B`TB)WTR)]NC/^/__
M2(D=7)0@`$F)WD&-10%(F$G'!,8`````3(GXZPEF#Q]$``!(_\"*"(3)=`6`
M^3UU\D0I^$B82(M-R$B-?`$"Z.OT__](A<!)8\U)B03.#X2`````2(L%")0@
M`$B+!,CK"&:02?_'2/_`08H/A,F("'0%@/D]=>S&`#VY`0````\?0`!!BE0,
M_X32B!0(2(U)`77PZS],`?M(_\-,BWW02(M%P`^$6_[__TB)W^C^]?__2#M%
MR',,32GU2<'M`^E5____08H$)$G_Q(3`B`-(C5L!=>](@\086T%<05U!7D%?
M7<-52(GEZPI(B<</'X``````2(U'`>L-9BX/'X0``````$C_P(I(_X3)=`>`
M^2]U\>O52(GX7<-F+@\?A```````54B)Y4%64TB)^TB%VP^$H0```$2*,T6$
M]@^$E0```$B)W^AE]?__2(U(_TB%R4B-1`/_?AYF9BX/'X0``````(`X+W4.
M2/_(2#G8=_/K!)!(_\A(.=AV!8`X+W7S2#G8=$Q(_\AF9BX/'X0``````$B)
MPD@IVG8)@#@O2(U`_W3O2(U"`D4Q]D@]``0``'<62/_"0;X`M6``OP"U8`!(
MB=[H!O;__TR)\%M!7EW#08#^+W4.O^^E0`!;05Y=Z6KT__^_5J1``.OP#Q^`
M`````%5(B>5!5T%6055!5%-(@^Q(2(L%R(T@`$B)1=`/*`5]/@``#RE%L`\H
M!6(^```/*46@9L=%P```3(LE,9(@`$V%Y`^$L@H``$&_8J-``+ABHT``ZPYF
M9BX/'X0``````$C_P(H(A,ET!X#Y/77R9I!-BRPD387M#X2(````1"GX3&/P
M3(GC9BX/'X0``````+YBHT``3(GO3(GRZ,ST__^%P'4(0X!\-0`]=!1,BVL(
M2(/#"$V%[777ZTH/'T0``$T![DF#_O]T/$PIXTC!ZP-(8\-)C43$"`\?A```
M````2(L(2(7)2(E(^$B-0`AU\$R+)7F1(`!-A>0/A4[____I]0D``$V%Y`^$
M[`D``$&_:Z-``+AKHT``ZP@/'T0``$C_P(H(A,ET!X#Y/77R9I!-BRPD387M
M#X2(````1"GX3&/P3(GC9BX/'X0``````+YKHT``3(GO3(GRZ`ST__^%P'4(
M0X!\-0`]=`],BVL(2(/#"$V%[777ZTI-`>Y)@_[_=$%,*>-(P>L#2&/#28U$
MQ`AF9F9F+@\?A```````2(L(2(7)2(E(^$B-0`AU\$R+);F0(`!-A>0/A53_
M___I-0D``$V%Y`^$+`D``$&_<Z-``+ASHT``ZP@/'T0``$C_P(H(A,ET!X#Y
M/77R9I!-BRPD387M#X2(````1"GX3&/P3(GC9BX/'X0``````+YSHT``3(GO
M3(GRZ$SS__^%P'4(0X!\-0`]=`],BVL(2(/#"$V%[777ZTI-`>Y)@_[_=$%,
M*>-(P>L#2&/#28U$Q`AF9F9F+@\?A```````2(L(2(7)2(E(^$B-0`AU\$R+
M)?F/(`!-A>0/A53____I=0@``$V%Y`^$;`@``$&_?*-``+A\HT``ZP@/'T0`
M`$C_P(H(A,ET!X#Y/77R9I!-BRPD387M#X2(````1"GX3&/P3(GC9BX/'X0`
M`````+Y\HT``3(GO3(GRZ(SR__^%P'4(0X!\-0`]=`],BVL(2(/#"$V%[777
MZTI-`>Y)@_[_=$%,*>-(P>L#2&/#28U$Q`AF9F9F+@\?A```````2(L(2(7)
M2(E(^$B-0`AU\$R+)3F/(`!-A>0/A53____IM0<``$V%Y`^$K`<``$&_@Z-`
M`+B#HT``ZP-(_\"*"(3)=`6`^3UU\DV++"1-A>T/A'\```!$*?A,8_!,B>.0
MOH.C0`!,B>],B?+HW/'__X7`=0A#@'PU`#UT#TR+:PA(@\,(387M==?K2DT!
M[DF#_O]T04PIXTC!ZP-(8\-)C43$"&9F9F8N#Q^$``````!(BPA(A<E(B4CX
M2(U`"'7P3(LEB8X@`$V%Y`^%9/___^D%!P``387D#X3\!@``0;^3HT``N).C
M0`#K`TC_P(H(A,ET!8#Y/77R38LL)$V%[0^$?P```$0I^$QC\$R)XY"^DZ-`
M`$R)[TR)\N@L\?__A<!U"$.`?#4`/70/3(MK"$B#PPA-A>UUU^M*30'N28/^
M_W1!3"GC2,'K`TACPTF-1,0(9F9F9BX/'X0``````$B+"$B%R4B)2/A(C4`(
M=?!,BR79C2``387D#X5D____Z54&``!-A>0/A$P&``!!OTRC0`"X3*-``.L#
M2/_`B@B$R70%@/D]=?)-BRPD387M#X1_````1"GX3&/P3(GCD+Y,HT``3(GO
M3(GRZ'SP__^%P'4(0X!\-0`]=`],BVL(2(/#"$V%[777ZTI-`>Y)@_[_=$%,
M*>-(P>L#2&/#28U$Q`AF9F9F+@\?A```````2(L(2(7)2(E(^$B-0`AU\$R+
M)2F-(`!-A>0/A63____II04``$V%Y`^$G`4``$&_GZ-``+B?HT``ZP-(_\"*
M"(3)=`6`^3UU\DV++"1-A>T/A'\```!$*?A,8_!,B>.0OI^C0`!,B>],B?+H
MS.___X7`=0A#@'PU`#UT#TR+:PA(@\,(387M==?K2DT![DF#_O]T04PIXTC!
MZP-(8\-)C43$"&9F9F8N#Q^$``````!(BPA(A<E(B4CX2(U`"'7P3(LE>8P@
M`$V%Y`^%9/___^GU!```387D#X3L!```0;^IHT``N*FC0`#K`TC_P(H(A,ET
M!8#Y/77R38LL)$V%[71V1"GX3&/P3(GC#Q]$``"^J:-``$R)[TR)\N@<[___
MA<!U"$.`?#4`/70/3(MK"$B#PPA-A>UUU^L]30'N28/^_W0T3"GC2,'K`TAC
MPTF-1,0(2(L(2(7)2(E(^$B-0`AU\$R+)=:+(`!-A>0/A7'____I4@0``$V%
MY`^$200``$&_LZ-``+BSHT``ZP-(_\"*"(3)=`6`^3UU\DV++"1-A>UT<T0I
M^$QC\$R)XV:0OK.C0`!,B>],B?+H?.[__X7`=0A#@'PU`#UT#TR+:PA(@\,(
M387M==?K/4T![DF#_O]T-$PIXTC!ZP-(8\-)C43$"$B+"$B%R4B)2/A(C4`(
M=?!,BR4VBR``387D#X5T____Z;(#``!-A>0/A*D#``!!OU6C0`"X5:-``.L#
M2/_`B@B$R70%@/D]=?)-BRPD387M='%$*?A,8_!,B>.^5:-``$R)[TR)\NC>
M[?__A<!U"$.`?#4`/70/3(MK"$B#PPA-A>UUU^L]30'N28/^_W0T3"GC2,'K
M`TACPTF-1,0(2(L(2(7)2(E(^$B-0`AU\$R+)9B*(`!-A>0/A7;____I%`,`
M`$V%Y`^$"P,``$&_O:-``+B]HT``ZP-(_\"*"(3)=`6`^3UU\DV++"1-A>UT
M>$0I^$QC\$R)X[Z]HT``3(GO3(GRZ$#M__^%P'4(0X!\-0`]=`],BVL(2(/#
M"$V%[777ZT1-`>Y)@_[_=#M,*>-(P>L#2&/#28U$Q`A(BPA(A<E(B4CX2(U`
M"'7P3(LE^HD@`$V%Y`^%=O___^EV`@``3(LEY8D@`$V%Y`^$9@(``+C&HT``
MZP-(_\"*"(3)=`6`^3UU\DV+/"1-A?]T9[G&HT``*<A,8_!,B?M-B>6^QJ-`
M`$B)WTR)\NB:[/__A<!U!T*`/#,]=`])BUT(28/%"$B%VW78ZRU)`=Y)@_[_
M="1-*>5)P>T#26/%28U$Q`A(BPA(A<E(B4CX2(U`"'7PZ6O___^XT:-``$V%
MY'4(Z=(!``!(_\"*"(3)=`6`^3UU\DV%_W15N=&C0``IR$QC\+L(````OM&C
M0`!,B?],B?+H$NS__X7`=0=#@#PW/70/38L\'$B#PPA-A?]UV.L<30'^2?_&
M=!2_J:-``$R)]NA'\___3(LEX(@@`+CBHT``387D=0CI6P$``$C_P(H(A,ET
M!8#Y/77R38L\)$V%_W15N>*C0``IR$QC\+L(````ON*C0`!,B?],B?+HE^O_
M_X7`=0=#@#PW/70/38L\'$B#PPA-A?]UV.L<30'^2?_&=!2_]*-``$R)]NC,
M\O__3(LE98@@`+C_HT``387D=0CIX````$C_P(H(A,ET!8#Y/77R28L<)$B%
MVT&^#Z1``'1HN?^C0``IR$QC^$V-;"0(0;X/I$``2(E=F+[_HT``2(M]F$R)
M^N@+Z___A<!U"TB+19A"@#PX/70328M%`$B)19A)@\4(2(7`=<_K'$P#?9A)
M_\=!O@^D0`!T#;],HT``3(G^ZWY)_\9!B@:$P'0$/#UU\DB%VW1+N`^D0`!!
M*<9-8_9)@\0(O@^D0`!(B=],B?+HGNK__X7`=0="@#PS/70/28L<)$F#Q`A(
MA=MUV.L220'>2?_&=`J_GZ-``$R)]NL@2(U]L;X@I$``N@H```#H7^K__X7`
M=0Y(C76[OY^C0`#HL?'__[^#HT``OBND0`#HHO'__TB+!:N"(`!(.T70=0](
M@\1(6T%<05U!7D%?7</HG>K__Y!52(GE05=!5D%44XL%7X(@`(/X_P^%E@``
M`$R+)?^&(`!-A>2XGZ-``$&W`74%ZW-(_\"*"(3)=`6`^3UU\DF+'"1(A=MT
M7+F?HT``*<A,8_!)@\0(9F8N#Q^$``````"^GZ-``$B)WTR)\NBLZ?__A<!U
M!T*`/#,]=`])BQPD28/$"$B%VW78ZQE)`=Y)_\9T$4&*!H3`#Y3!/#!!#Y3'
M00C/00^VQX/P`8D%P($@`%M!7$%>05]=PP\?@`````!52(GEZ"/I__^)Q^@\
MY___2(G!,<!(A<ET`TB+`5W#D%5(B>5!5T%6055!5%-(@^Q(2(E]F`]7P`\I
M1<`/*46P#RE%H$C'1=``````2,=%H#>D0`!!OS>D0`!(QT6H+:1``$C'1;`Z
MI$``2,=%N#"D0`!(QT7`-:1``$C'1<A'I$``13'MZUE,B>=(BW68Z+GI__](
MA<`/A?````!,BW683(GWZ`3H__](C7P#`NAZYO__2(G#OH6D0`"Y]Z5``#'`
M2(G?3(GR38G@Z)WG__],B?](B=[IK0```&8/'T0``$R+-7F%(`!-A?9,B?@/
MA(T```#K#F9F+@\?A```````2/_`B@B$R70'@/D]=?)FD$F+'DB%VW1H1"GX
M3&/@28/&"&9F9F9F+@\?A```````2(G?3(G^3(GBZ![H__^%P'4'0H`\(SUT
M#DF+'DF#Q@A(A=MUV^LI20'<2?_$="%,B>?H1>?__TB)PTB%VP^%%/___V9F
M9F8N#Q^$``````!,B?](BW68Z#3O__].BWSMJ$G_Q4V%_P^%0____TB#Q$A;
M05Q!74%>05]=PP\?0`!52(GE05=!5D%505132('L.($``$F)_$B+!0*`(`!(
MB470#U?`#RF%<'___P\IA6!___\/*850?___2,>%4'____2C0`!(QX58?___
M[:-``$C'A6!___]8I$``2,>%:'___PJD0`!(QX5P?___8*1``$R+/3B$(`!-
MA?^X3*-``'41Z8@```!F#Q^$``````!(_\"*"(3)=`6`^3UU\DF+'TB%VW1I
MN4RC0``IR$QC\$F#QPAF9F8N#Q^$``````"^3*-``$B)WTR)\NC<YO__A<!U
M!T*`/#,]=`Y)BQ])@\<(2(7;==GK)DD!WDG_QG0>08`^`'083(GWZ'']__],
MB??HE>7__TF)Q>D;!```3(FEP'[__^AAYO__B<?H>N3__T4Q_TB%P'062(L`
M13'_2(7`#X7P````#Q^``````$R+-6F#(``QP$B)A<A^__]-A?8/A+<```!.
MBR3]D&5``$R)X.L-9BX/'X0``````$C_P(H(A,ET!X#Y/77R9I!)BQXQR4B)
MC<A^__](A=MT?T0IX$QCZ$F#Q@@QP$B)A<A^__]F9F8N#Q^$``````!(B=],
MB>9,B>KH[N7__X7`=0="@#PK/70.28L>28/&"$B%VW7;ZSE)`=TQP$B)A<A^
M__])_\5T*#'`2(F%R'[__T&`?0``=!A,B>_HG.3__TB)A<A^__]F#Q^$````
M``!(BX7(?O__2(7`=0U)_\=!@_\"#X(7____2(7`0;QWI$``3`]%X$R)Y^B^
MY/__2(U\``'H-./__TB)A<A^__]!B@0D13'_A,!!O?2C0`!T4$G_Q$B+G<A^
M__]F#Q]$```/MM"^?J1``#'`2(G?Z#KD__](@\,"08H$)$G_Q(3`==],BZU0
M?___13'_387M0;X`````#X39````9@\?1```3(LU^8$@`$V%]@^$D````$R)
MZ.L.9F8N#Q^$``````!(_\"*"(3)=`>`^3UU\F:028L>2(7;=&A$*>A,8^!)
M@\8(9F9F9F8N#Q^$``````!(B=],B>Y,B>+HGN3__X7`=0="@#PC/70.28L>
M28/&"$B%VW7;ZRE)`=Q)_\1T(4&`/"0`=!I,B>?H\@D``(7`=2=F9F9F9BX/
M'X0``````$Z+K/U8?___2?_'13'V387M#X5)____ZQI,B>?H*^/__TF)QT4Q
M]DV%_W4\ZP5FD$G_QD4Q_T&#_@%W+$J+'/5P94``13'_@#L`=!Q(B=_HC`D`
M`(7`=-A(B=_H[.+__TF)QTV%_W3(3(G_Z#SC__](B<-,B[7(?O__3(GWZ"KC
M__^-1`,$2,'@($F]```````$``!)`<5)P?T@3(GOZ(GA__])B<1,B:6X?O__
MOH.D0`"Y5J1``$&X<J1``#'`3(GG3(GZ38GQZ)_B__^^P`$``$R)Y^ABX___
M@_C_=0[H*.3__X,X$0^%O````(L]S7L@`.BTX___2(VPF`$``$R)Y^@5X___
MA<!U>8L]KWL@`.B6X___#[>`H`$``"4`\```9CT`0'5<BSV2>R``Z'GC__^+
MF*0!``#H[N+__SG#=4*+/7A[(`#H7^/__P^W@*`!```E_P$``&8]P`%U)4R)
M[^C%X/__28G%3(L][W\@`$V%_[@PI$``#X6%````Z0(!``!(BSVM>R``2(N%
MP'[__TB+$$4Q[;['I$``,<!,B>'HM>'__^LQ3(LUB'L@`$B+A<!^__](BQCH
M3>/__T2+`$4Q[;Z,I$``,<!,B?=(B=I,B>'H@N'__TB+!>]Z(`!(.T70=15,
MB>A(@<0X@0``6T%<05U!7D%?7</HV^+__TC_P(H(A,ET!8#Y/77R28L?2(7;
M=&^Y,*1``"G(3&/P28/'"&9F+@\?A```````OC"D0`!(B=],B?+H'.+__X7`
M=0="@#PS/70.28L?28/'"$B%VW79ZRU)`=Y)_\9T)4B+A<!^__](BQA,B??H
MV>#__TB)WTB)QN@"Y___28G&387V=0I(BX7`?O__3(LP3(GWZ!3A__](B<.#
M^P1\:DACPTJ-?##\OAJE0`#H.N/__X7`=52#^P1T'$C!XR!(N`````#[____
M2`'82,'X($&`/`8O=3-(BX7`?O__2(M8"$B%VW0C2(G?Z+W@__](@_@$<A5(
MC7P8_+X?I4``Z.CB__^%P$P/1/.+!:!Y(`"#^/\/A;,```!,B:VH?O__3(LM
M.7X@`$V%[;B?HT``L@%U#TR+K:A^___I@0```$C_P(H(A,ET!8#Y/77R28M=
M`$B%VW1!N9^C0``IR$QC^$F#Q0B^GZ-``$B)WTR)^NCHX/__A<!U!T*`/#L]
M="%)BUT`28/%"$B%VW783(NMJ'[__[(!ZRE,BZVH?O__ZR!)`=])_\=,BZVH
M?O__L@%T#T&*!X3`#Y3!/#`/E,((R@^VPH/P`8D%Y'@@`(7`#X43`0``,?8Q
MP$R)]^B<WO__08G&1(FUP'[__T6%]@^$]````$C'QN[___^Z`@```$2)]^B5
MW___2(VUH'___[H&````1(GWZ,'?__](BX6@?___#[?(2('Y`$,```^%5P$`
M`(G!P>D0@/E!#X5)`0``N0```/\CC:!___^!^0```$,/A3(!``!(N0````#_
M````2"'!2+H`````2````$@YT0^%$@$``$BY``````#_``!((<A(N0``````
M10``2#G(#X7R````2,?&QO___[H"````1(GWZ/'>__](C9V@?___NBD```!$
MB?=(B=[H&M___[XDI4``N5:D0`!!N;^E0``QP$R)[TR)XDF)V.B*WO__Z=0$
M``"_GZ-``+XKI$``Z,KF___H8>#__XG#OC.E0`"Y5J1``$&YOZ5``#'`3(GO
M3(GB08G8Z$_>__^^P`$``$R)[^@2W___@_C_#X6(!```NP$```#HS]___X,X
M$0^%=00``.@1X/__08G`2,<$)+^E0`"^0:5``+E6I$``,<!,B>),B>]!B=GH
M_-W__[[``0``3(GOZ+_>____PX/X_W2TZ3($``!,B:VH?O__,?8QTD2)]^@`
MWO__2,>%T'[__P$C16>XB:O-[TB)A=A^__^X_MRZF$B)A>!^__](QX7H?O__
M=E0R$+CPX=+#2(F%\'[__\>%2'___P`````/5\`/$87X?O__2(VUH'___[H`
M@```1(GWZ-[=__])B<5%A>T/CHD!``!(C9T(?___3(V]T'[__TR)Z$ACR$C!
MX`-(B[7X?O__2(N5`'___P'P2#GP<PI(_\)(B94`?___2(F%^'[__TC!Z1U(
M`=%(B8T`?___2&.%2'___TB%P'4,2(V%H'___TB)QNMAN4`````IP40YZ4$/
M3\U(C;P%"'___TQC\4B-M:!___],B?+HEM[__XN%2'___T0!\(/X0(F%2'__
M_P^%O@```$J-A#6@?___2(F%R'[__T4I]4R)_^BX#@``2(NUR'[__T&#_4`/
MC'X```!!C47`B86T?O__08G$0<'L!D'!Y`9)B?9(B;7(?O__#Q^$``````!!
M#Q`&00\03A!!#Q!6($$/$%XP#Q%;,`\14R`/$4L0#Q$#28/&0$&#Q<!,B?_H
M3@X``$&#_3]_R(N%M'[__T0IX$B+M<A^__])C70T0$&)Q4R+I;A^__]-8_5(
MB=],B?+HQ]W__T2)M4A___^Z`(```$2+M<!^__]$B?=(C;6@?___Z%7<__])
MB<5%A>T/CXC^__]$B??HX=O__TB+G?A^__],B[4`?___B=K!Z@.#XC^-0@&#
M^#G&A!4(?___@$B-O`4(?___<CN#\C\Q]NB9W?__2(V]T'[__^BA#0``#U?`
M#Q&%*'___P\1A1A___\/$84(?___2,>%.'___P````#K$;@W````*=!(8]`Q
M]NA7W?__3(NMJ'[__TR)\4B)R$C!Z!B(A4!___](B<A(P>@0B(5!?___B*U"
M?___B(U#?___2(G82,'H&(B%1'___TB)V$C!Z!"(A45___^(O49___^(G4=_
M__](C;W0?O__Z`D-``!(BXW0?O__2(G(2,'H&(B%@'___TB)RDC!ZA"(E8%_
M__^(K8)___^(C8-___](BXW8?O__2(G*2,'J&(B5A'___TB)RDC!ZA"(E85_
M__^(K89___^(C8=___](BXW@?O__2(G*2,'J&(B5B'___TB)RDC!ZA"(E8E_
M__^(K8I___^(C8M___](BXWH?O__2(G*2,'J&(B5C'___TB)RDC!ZA"(E8U_
M__^(K8Y___^(C8]___](BXWP?O__2(G*2,'J&(B5D'___TB)RDC!ZA"(E9%_
M__^(K9)___^(C9-___],C76@NP$```#K&V9F9F8N#Q^$``````"*A!V`?___
M28/&`DC_PP^VT+Y^I$``,<!,B??HW-G__TB#^Q1UVL9%R`!,C46@OB2E0`"Y
M5J1``$&YOZ5``#'`3(GB3(GOZ+'9__],B>?HV=O__[],HT``3(GNZ/#A__],
MB>_H2/'__^G]]___#Q\`54B)Y5-02(G[BSW1<B``Z+C:__](C;"8`0``2(G?
MZ!G:__^%P'0$,<#K4(L]KW(@`.B6VO__#[>`H`$``"4`\```9CT`0'0=BSV2
M<B``Z'G:__\/MX"@`0``)0#P``!F/0"@=12^`@```$B)W^AJVO__A<`/E,#K
M`C'`#[;`2(/$"%M=PV9F+@\?A```````54B)Y4%7059!54%44U!)B?_HFN/_
M_TF)QDF-1@'K!)!(_\"*2/^$R70'@/DO=?'KY8L%"7(@`(/X_P^%H@```$R+
M+:EV(`!-A>VXGZ-``+(!=1#I?@````\?A```````2/_`B@B$R70%@/D]=?))
MBUT`2(7;=%^YGZ-``"G(3&/@28/%"&9F+@\?A```````OI^C0`!(B=],B>+H
M3-G__X7`=0="@#PC/70128M=`$F#Q0A(A=MUV+(!ZQI)`=Q)_\2R`70008H$
M)(3`#Y3!/#`/E,((R@^VPH/P`8D%7G$@`(7`="%-A?]T'$&`/P!T%KYRI$``
MN@0```!,B??HZ=C__X7`=`](@\0(6T%<05U!7D%?7<-,B?](@\0(6T%<05U!
M7D%?7>L'#Q^``````%5(B>5!5T%6055!5%-(@^QX28G^387V#X0;`0``08`^
M``^$$0$``$R)]^A-V?__28G$387D#X3]````3(GGZ"G7__](B<-(A=L/A-D`
M``!,C;U@____9BX/'X0``````$B#PPB^[Z5``$B)W^C;V?__A<`/A)L```"^
M[J5``$B)W^C&V?__A<`/A(8```!,B??H=M?__TF)Q4B)W^AKU___08U\!0%(
MP><@2+@``````0```$@!QTC!_R#HS-7__TF)Q;[QI4``,<!,B>],B?)(B=GH
M]-;__TR)[TR)_NB9UO__@_C_=!P/MX5H____)0#P``!F/0!`=0I,B>_H_O[_
M_^L(3(GOZ%#6__],B>_HZ-C__TR)Y^A0UO__2(G#2(7;#X4X____3(GGZ`S9
M__],B??H=-?__TB#Q'A;05Q!74%>05]=PV8/'X0``````%5(B>5!5T%6055!
M5%-(@>P(!```2(L%Q6\@`$B)1="+/:MO(`#HDM?__\:`J0````%(BQTX="``
M2(7;N(.C0`!U$>M[9F9F+@\?A```````2/_`B@B$R70%@/D]=?),BSM-A?]T
M6;F#HT``*<A,8_!(@\,(9F9F+@\?A```````OH.C0`!,B?],B?+HW-;__X7`
M=0=#@#PW/70.3(L[2(/#"$V%_W79ZQ9+C00^2/_`=`V`.#%U"$.`?#X"`'0%
MZ#SA__^+/09O(`#H[=;__[Y2I4``N@$```"Y"P```$B)Q^CFU/__2(7`#X0'
M`0``13'DB@U8<R``A,D/A/8```!(BT`03(MP*$&]``0@`&:0BSVZ;B``Z*'6
M__\QR4B)QTR)]DR)XNAAUO__2(G#2(7;='I(BP4><R``3HM\X`A(BP.+2`Q$
M(>F!^0`$``!U$$B+<!#K*F8N#Q^$``````"+/6IN(`#H4=;__TB+,S'2N0(`
M``!(B<?HG]?__TB)QDR)_^ATU___A<!U(8H%OG(@``^VR(/A`<'A`DG_Q$&-
M5"0!.<H/C&7____K!HH%G7(@``^VR(/A`8T,C?____]!.<QU,30!J`%U*[L!
M````BSWZ;2``Z.'5__](B<=,B?;HUM/____##[8%87(@`,'@`CG#?-J+/=1M
M(`#HN]7__[Y7I4``N@$```"Y`P```$B)Q^BTT___2(G#2(7;=#"+/:IM(`#H
MD=7__TB+2Q!(BS&Z6:5``$B)Q^B=T___2(M#$$B+`/9`#D`/A90"``"+/7IM
M(`#H8=7__[[/HT``N@$```"Y`P```$B)Q^A:T___28G&387V#X1``0``3(LM
MZW$@`$4Q_TV%[;A5HT``=1'K:V9F9BX/'X0``````$C_P(H(A,ET!8#Y/77R
M28M=`$4Q_TB%VW1%N56C0``IR$QCX$F#Q0A%,?\/'T0``+Y5HT``2(G?3(GB
MZ(S4__^%P'4'0H`\(SUT#TF+70!)@\4(2(7;==CK!4V-?!P!BSW+;"``Z++4
M__]-A?])BTX03(LQ#X66````2(L%-W$@`$R+.$B-M=#[__^_VZ5``+K_`P``
MZ$+2__^%P'YG2(G!2,'A($BZ`````/____](`<I(P?H@@+P5T/O__P!U!XU`
M_X7`?CY(8]A(C;W0^___OB\```!(B=KHGM/__TB%P'0BBSU';"``Z"[4__](
MC970^___2(G'3(GV2(G9Z-G3___K&8L])6P@`.@,U/__2(G'3(GV3(GZZ![2
M__^+/0QL(`#H\]/__\:`J0````!,BSV9<"``387_N$RC0`!U$NMD9F9F9BX/
M'X0``````$C_P(H(A,ET!8#Y/77R28L?2(7;=$&Y3*-``"G(3&/P28/'"&9F
M9BX/'X0``````+Y,HT``2(G?3(GRZ#S3__^%P'4'0H`\,SUT>TF+'TF#QPA(
MA=MUV4C'!0YP(```````2(L]_V\@`.ABZ___28G&387V3(DU]6\@``^$D@``
M`+[``0``3(GWZ,[2__^)P8U!`8/X$G<_N@,`!``/H\)S-4B+!4=K(`!(.T70
M=1)(@<0(!```6T%<05U!7D%?7</H-M/__TD!WDG_QDR)-9UO(`!UK.N+2(L%
MBF\@`$B+,$B+%8AO(`"_?Z5``#'`Z&C3__^+/>9J(`#HS=+__TB+2Q!(BS%(
MB<?H_M+__^E-_?__OUZE0``QP.@]T___D%5(B>5!5T%6055!5%-(@^PHB7W4
M2(EUR$B)5<!(C7W42(UUR$B-5<#HC]/__[^,&T``ODP:0`"Z3!I``.A+TO__
M,=N`/<9J(```=2OHV]#__TB)PTB%VP^$GP(``$B)W^B7T?__BSU5:B``Z#S2
M___&@)T'````BSU#:B``Z"K2__^`B+H#```"BSTQ:B``Z!C2__^`B+H#```!
MBT74@\`%2&/X9D@/;L=F#V(%?QH``&8/7`6'&@``9@]PR$YF#UC(9@\N#98:
M```/AS8"``!(P><#Z*/2__](B05H;B``2(MUR$B+#DB)"$C'0`C`I4``2(L-
MKVD@`$B)2!!(QT`8PZ5``,8%-&X@``&+3=2#^0*Z`0```'Q528G92+L`````
M!````$FX``````$```#K'&9F9F9F+@\?A```````2(MUR$B+!?UM(`!,`<-(
MBS362(G?2,'_($B)-/A(_\(YRGS<2(L%W6T@`$R)RX/!`TACT4C'!-``````
M2(L-Q6T@`+[@3$``13'`2(G?Z,G.__]!B<=%A?]U"TB)W^CYSO__08G'2(G?
M2(E=N.CJT/__3(LMIVT@`$V%[;B3HT``=1#K<69F+@\?A```````2/_`B@B$
MR70%@/D]=?))BUT`2(7;=$^YDZ-``"G(3&/@38UU"&9F+@\?A```````OI.C
M0`!(B=],B>+H3-#__X7`=0="@#PC/70.28L>28/&"$B%VW79ZPU)`=Q)@_S_
M#X6F````3(LE$VT@`$V%Y`^%C@```+A,HT``387M=1/K9F9F9F9F+@\?A```
M````2/_`B@B$R70%@/D]=?))BUT`2(7;=$&Y3*-``"G(3&/@28/%"&9F+@\?
MA```````ODRC0`!(B=],B>+HO,___X7`=0="@#PC/70:28M=`$F#Q0A(A=MU
MV$C'!8UL(```````ZQ=)`=Q)_\1,B25^;"``=`A,B>?HE/7__TB+?;CH5\W_
M_^BBSO__1(GX2(/$*%M!7$%=05Y!7UW#OP$```#HAM#__[])HT``ON"T8``Q
MP.@ET/__9@\?A```````54B)Y8L]EF<@`.A]S___BSV+9R``Z'+/__^^J&5`
M`+I\&T``N3!E0`!(B<?H6]#__XL]:6<@`.A0S___OL:E0`"ZL$1``+F_I4``
M0;B_I4``13')2(G'7>EOSO__#Q\`54B)Y4%7059!54%44TB![`@"``!%,<!F
M#Q^$``````!*BTR'.$B)RDB!XO\```!(P>(82(G.2,'F"$B!Y@``_P!("=9)
MB<E)P>D(3(G*2('B`/\``$@)\DB)SDC![AA`#[;&2`G02HF$Q5#]__]!@>$`
M``#_2('F``#_`$B)R$C!Z"A()0#_``!(P>DX2`G!2`GQ3`G)2HF,Q5C]__])
M@\`"08/X$`^,=/___S'`9I!(BXS%D/W__T@SC,6X_?__2#.,Q6#]__](,XS%
M4/W__TB)RDC!ZA](C0P)"=%(B8S%T/W__TC_P$B#^$!UPDR+!TB+5PA,BU<0
M3(M/&$R)P$C!X`5,B<9(P>X;2`G&3(G02"'02(G12/?13"')2`G!2(N%4/W_
M_T@#=R!(`<Y(C80PF7F"6D&)PTB)UDC!YAY(P>H"2`GR08G63(G92,'I&TR)
MVTB!X____P=(P>,%2`G+3(GQ3"'!3(G&2/?63"'62`G.3`'.2`.U6/W__TB-
MC#.9>8):08G)3(G#2,'C'DV)Q$G![`))"=Q%B>=,B<M(P>L;3(G.2('F____
M!TC!Y@5("=Y(B<-,(?OWT$PA\$@)V$P#E6#]__])`<)*C806F7F"6D&)PDR)
MVTC!ZP))@^,#2<'C'DD)VTR)UDC![AM,B=-(@>/___\'2,'C!4@)\TB)SDPA
MWO?13"'Y2`GQ2`.5:/W__T@!RDB-C!.9>8):08G/3(G.2,'N`DF#X0-)P>$>
M20GQ3(G^2,'N&TR)^TB!X____P=(P>,%2`GS2(G&3"'.]]!,(=A("?!,`Z5P
M_?__20'$2HV$(YEY@EI!B<9,B=-(P>L"28/B`TG!XAY)"=I,B?-(P>L;3(GV
M2('F____!TC!Y@5("=Y(B<M,(=/WT4PAR4@)V4P#G7C]__])`<M*C8P>F7F"
M6HG+3(GZ2,'J`DF#YP-)P><>20G72(G:2,'J&TB)WDB!YO___P=(P>8%2`G6
M2(G"3"'Z]]!,(=!("=!,`XV`_?__20'!2HV$#IEY@EI!B<%,B?9(P>X"28/F
M`TG!YAY)"?9,B<Y(P>X;3(G*2('B____!TC!X@5("?)(B<Y,(?;WT4PA^4@)
M\4P#E8C]__])`<I*C8P2F7F"6D&)RDB)WDC![@)(@^,#2,'C'D@)\TR)UDC!
M[AM,B=)(@>+___\'2,'B!4@)\DB)QD@AWO?03"'P2`GP3`.]D/W__TD!QTJ-
MA#J9>8):08G#3(G.2,'N`DF#X0-)P>$>20GQ3(G>2,'N&TR)VDB!XO___P=(
MP>(%2`GR2(G.3"'.]]%((=E("?%,`[68_?__20'.2HV,,IEY@EI!B<Y,B=9(
MP>X"28/B`TG!XAY)"?),B?9(P>X;3(GR2('B____!TC!X@5("?)(B<9,(=;W
MT$PAR$@)\$@#G:#]__](`<-(C80:F7F"6D&)QTR)WDC![@))@^,#2<'C'DD)
M\TR)_DC![AM,B?M(@>/___\'2,'C!4@)\TB)SDPAWO?13"'12`GQ3`.-J/W_
M_TD!R4J-C`N9>8):08G)3(GS2,'K`DF#Y@-)P>8>20G>3(G.2,'N&TR)RTB!
MX____P=(P>,%2`GS2(G&3"'V]]!,(=A("?!,`Y6P_?__20'"2HV$$YEY@EI!
MB<),B?I(P>H"28/G`TG!YQY)"==,B=)(P>H;3(G62('F____!TC!Y@5("=9(
MB<I,(?KWT4PA\4@)T4P#G;C]__])`<M*C8P>F7F"6D&)RTR)SDC![@))@^$#
M2<'A'DD)\4R)WDC![AM,B=I(@>+___\'2,'B!4@)\DB)QDPASO?03"'X2`GP
M3`.UP/W__TD!QDJ-A#*9>8):08G&3(G62,'N`DF#X@-)P>(>20GR3(GV2,'N
M&TR)\DB!XO___P=(P>(%2`GR2(G.3"'6]]%,(<E("?%,`[W(_?__20'/2HV,
M.IEY@EI!B<],B=Y(P>X"28/C`TG!XQY)"?-,B?Y(P>X;3(GZ2('B____!TC!
MX@5("?)(B<9,(=[WT$PAT$@)\$P#C=#]__])`<%*C80*F7F"6D&)P4R)]DC!
M[@))@^8#2<'F'DD)]DR)SDC![AM,B<I(@>+___\'2,'B!4@)\DB)SDPA]O?1
M3"'92`GQ3`.5V/W__TD!RDJ-C!*9>8):08G,3(G^2,'N`DF#YP-)P><>20GW
M3(GF2,'F!4R)XDC!ZAM("?)(B<9,(?[WT$PA\$@)\$P#G>#]__])`<-.C90:
MF7F"6D6)U4R)SDC![@))@^$#2<'A'DD)\4R)[DC!Y@5,B>I(P>H;2`GR2(G.
M3"'.]]%,(?E("?%,`[7H_?__20'.3HV<,IEY@EI$B=M,B>9(P>X"28/D`TG!
MY!Y)"?1(B=Y(P>8%2(G:2,'J&T@)\DR)YDPQSDPQUDP#O?#]__])`?=.C90Z
MH>O9;D6)UDR)Z$C!Z`))@^4#2<'E'DD)Q4R)\$C!X`5,B?9(P>X;2`G&3(GH
M3#'@3#'83`.-^/W__TD!P4Z-C`ZAZ]EN18G+2(G92,'I`DB#XP-(P>,>2`G+
M3(G92,'A!4R)WDC![AM("<Y(B=E,,>E,,=%,`Z4`_O__20',3HV4)J'KV6Y%
MB==,B?)(P>H"28/F`TG!YAY)"=9,B?I(P>(%3(G^2,'N&T@)UDR)\D@QVDPQ
MRDP#K0C^__])`=5.C8PNH>O9;D6)S$R)V$C!Z`))@^,#2<'C'DD)PTR)X$C!
MX`5,B>9(P>X;2`G&3(G83#'P3#'02`.=$/[__T@!PTR-E!ZAZ]EN18G53(GY
M2,'I`DF#YP-)P><>20G/3(GI2,'A!4R)[DC![AM("<Y,B?E,,=E,,<E,`[48
M_O__20'.3HV,-J'KV6Y%B<Y,B>)(P>H"28/D`TG!Y!Y)"=1,B?)(P>(%3(GV
M2,'N&T@)UDR)XDPQ^DPQTDP#G2#^__])`=-.C90>H>O9;D6)TTR)ZTC!ZP))
M@^4#2<'E'DD)W4R)WDC!Y@5,B=E(P>D;2`GQ3(GN3#'F3#'.3`.]*/[__TD!
M]TJ-C#FAZ]ENB<M,B?!(P>@"28/F`TG!YAY)"<9(B=A(P>`%2(G>2,'N&T@)
MQDR)\$PQZ$PQT$P#I3#^__])`<1.C8PFH>O9;D6)STR)VDC!Z@))@^,#2<'C
M'DD)TTR)^DC!X@5,B?Y(P>X;2`G63(G:3#'R2#'*3`.M./[__TD!U4Z-E"ZA
MZ]EN18G42(G>2,'N`DB#XP-(P>,>2`GS3(GF2,'F!4R)XDC!ZAM("?)(B=Y,
M,=Y,,<Y,`[5`_O__20'V3HV,,J'KV6Y%B<Y,B?A(P>@"28/G`TG!YQY)"<=,
MB?!(P>`%3(GV2,'N&T@)QDR)^$@QV$PQT$P#G4C^__])`<-.C90>H>O9;D6)
MTTR)X4C!Z0))@^0#2<'D'DD)S$R)V4C!X05,B=Y(P>X;2`G.3(GA3#'Y3#')
M2`.=4/[__T@!RTR-C!ZAZ]EN18G-3(GR2,'J`DF#Y@-)P>8>20G63(GJ2,'B
M!4R)[DC![AM("=9,B?),,>),,=),`[U8_O__20'73HV4/J'KV6Y$B=),B=A(
MP>@"28/C`TG!XQY)"<-(B=!(P>`%2(G62,'N&T@)QDR)V$PQ\$PQR$P#I6#^
M__])`<1.C8PFH>O9;D6)STR)ZTC!ZP))@^4#2<'E'DD)W4R)_DC!Y@5,B?A(
MP>@;2`GP3(GN3#'>3#'63`.U:/[__TD!]DZ-E#"AZ]EN18G62(G12,'I`DB#
MX@-(P>(>2`G*3(GQ2,'A!4R)]DC![AL)\8G61#'N1#'.1`.=</[__T$!\T:-
MG!FAZ]EN3(G^2,'N`DF#YP-)P><>20GW3(G>2,'F!4R)V4C!Z1L)SD2)^3'1
M1#'11`.M>/[__T$!S4:-I"ZAZ]EN3(GV2,'N`DF#Y@-)P>8>20GV3(GF2,'N
M&TR)X4B!X?___P=(P>$%2`GQ3(GV3#'^3#'>2`.5@/[__T@!\DR-C!&AZ]EN
M18G-3(G>2,'N`DF#XP-)P>,>20GS3(GN2,'N&TR)ZDB!XO___P=(P>(%2`GR
M3(G>3#'V3#'F3`.]B/[__TD!]TZ-E#JAZ]EN18G73(GC2,'K`DF#Y`-)P>0>
M20G<3(G^2,'N&TR)^TB!X____P=(P>,%2`GS3(GF3`G>3"'.3(G@3"'82`GP
M3`.UD/[__TD!QDD!WD&YW+P;CTT!SD2)\TR)Z4C!Z0))@^4#2<'E'DD)S4B)
MV4C!Z1M(B=Y(@>;___\'2,'F!4@)SDR)Z4P)X4PAT4R)Z$PAX$@)R$P#G9C^
M__])`<-)`?--`<M%B=I,B?E(P>D"28/G`TG!YQY)"<],B=%(P>D;3(G62('F
M____!TC!Y@5("<Y,B?E,">E,(?%,B?I,(>I("<I,`Z6@_O__20'420'T30',
M18GF2(G:2,'J`DB#XP-(P>,>2`G33(GR2,'J&TR)]DB!YO___P=(P>8%2`G6
M2(G:3`GZ3"':2(G83"'X2`G03`.MJ/[__TD!Q4D!]4T!S46)ZTR)TDC!Z@))
M@^(#2<'B'DD)TDR)VDC!ZAM,B=Y(@>;___\'2,'F!4@)UDR)TD@)VDPAXDR)
MT$@AV$@)T$P#O;#^__])`<=)`?=-`<]%B?Q,B?)(P>H"28/F`TG!YAY)"=9,
MB>)(P>H;3(GF2('F____!TC!Y@5("=9,B?),"=),(>I,B?%,(=%("=%(`YVX
M_O__2`'+2`'S3`'+08G=3(G:2,'J`DF#XP-)P>,>20G33(GJ2,'J&TR)[DB!
MYO___P=(P>8%2`G63(G:3`GR3"'Z3(G83"'P2`G03`.5P/[__TD!PDD!\DT!
MRD6)UTR)XDC!Z@))@^0#2<'D'DD)U$R)^DC!ZAM,B?Y(@>;___\'2,'F!4@)
MUDR)XDP)VD@AVDR)XTPAVT@)TTP#M<C^__])`=Y)`?9-`<Y$B?),B>Y(P>X"
M28/E`TG!Y1Y)"?5(B=9(P>X;2(G32('C____!TC!XP5("?-,B>Y,">9,(=9,
MB>E,(>%("?%,`YW0_O__20'+20';30'+1(G;3(G^2,'N`DF#YP-)P><>20GW
M2(G>2,'N&TB)V4B!X?___P=(P>$%2`GQ3(G^3`GN3"'V3(GX3"'H2`GP3`.E
MV/[__TD!Q$D!S$T!S$6)XDB)T4C!Z0)(@^(#2,'B'D@)RDR)T4C!Z1M,B=9(
M@>;___\'2,'F!4@)SDB)T4P)^4PAV4B)T$PA^$@)R$P#K>#^__])`<5)`?5-
M`<U%B>M(B=E(P>D"2(/C`TC!XQY("<M,B=E(P>D;3(G>2('F____!TC!Y@5(
M"<Y(B=E("=%,(>%(B=A((=!("<A,`[WH_O__20''20'W30'/18G^3(G12,'I
M`DF#X@-)P>(>20G*3(GQ2,'I&TR)]DB!YO___P=(P>8%2`G.3(G12`G93"'I
M3(G02"'82`G(2`.5\/[__T@!PD@!\DP!RD&)U$R)V4C!Z0))@^,#2<'C'DD)
MRTR)X4C!Z1M,B>9(@>;___\'2,'F!4@)SDR)V4P)T4PA^4R)V$PAT$@)R$@#
MG?C^__](`<-(`?-,`<M!B=],B?%(P>D"28/F`TG!YAY)"<Y,B?E(P>D;3(G^
M2('F____!TC!Y@5("<Y,B?%,"=E((=%,B?),(=I("<I,`Y4`____20'220'R
M30'*18G53(GB2,'J`DF#Y`-)P>0>20G43(GJ2,'J&TR)[DB!YO___P=(P>8%
M2`G63(GB3`GR2"':3(GC3"'S2`G33`.="/___TD!VTD!\TT!RT2)VDR)_DC!
M[@))@^<#2<'G'DD)]TB)UDC![AM(B=-(@>/___\'2,'C!4@)\TR)_DP)YDPA
MUDR)^$PAX$@)\$P#M1#___])`<9)`=Y-`<Y$B?-,B>Y(P>X"28/E`TG!Y1Y)
M"?5(B=Y(P>X;2(G82"7___\'2,'@!4@)\$R)[DP)_DPAWDR)Z4PA^4@)\4P#
MI1C___])`<Q)`<1-`<Q%B>)(B=%(P>D"2(/B`TC!XAY("<I,B=%(P>$%3(G6
M2,'N&T@)SDB)T4P)Z4PA\4B)T$PAZ$@)R$P#O2#___])`<=)`?=-`<]%B?M(
MB=E(P>D"2(/C`TC!XQY("<M,B=E(P>$%3(G>2,'N&T@)SDB)V4@)T4PAX4B)
MV$@AT$@)R$P#K2C___])`<5)`?5-`<U%B>Y,B=%(P>D"28/B`TG!XAY)"<I,
MB?%(P>$%3(GV2,'N&T@)SDR)T4@QV4PQ^4@#E3#___](`<I(`?)!N=;!8LI,
M`<J)T$R)V4C!Z0))@^,#2<'C'DD)RTB)P4C!X05(B<9(P>X;2`G.3(G93#'1
M3#'I2`.=./___T@!RT@!\TP!RT&)WTR)]DC![@))@^8#2<'F'DD)]DR)_DC!
MY@5,B?E(P>D;2`GQ3(GV3#'>2#'63`.50/___TD!\DD!RDT!RD6)U$B)PDC!
MZ@)(@^`#2,'@'D@)T$R)XDC!X@5,B>9(P>X;2`G62(G"3#'R2#':3`.=2/__
M_TD!TTD!\TT!RT2)VDR)_DC![@))@^<#2<'G'DD)]TB)UDC!Y@5(B=-(P>L;
M2`GS3(G^2#'&3#'63`.U4/___TD!]DD!WDT!SD2)\TR)X4C!Z0))@^0#2<'D
M'DD)S$B)V4C!X05(B=Y(P>X;2`G.3(GA3#'Y3#'92`.%6/___T@!R$@!\$P!
MR$&)PDB)UDC![@)(@^(#2,'B'D@)\DR)UDC!Y@5,B=%(P>D;2`GQ2(G63#'F
M3#'V3`.]8/___TD!]TD!STT!ST6)^TB)WDC![@)(@^,#2,'C'D@)\TR)WDC!
MY@5,B=E(P>D;2`GQ2(G>2#'62#'&3`.E:/___TD!]$D!S$T!S$2)X$R)T4C!
MZ0))@^(#2<'B'DD)RDB)P4C!X05(B<9(P>X;2`G.3(G12#'93#'Y2`.5</__
M_T@!RD@!\DP!RD&)UDR)WDC![@))@^,#2<'C'DD)\TR)]DC!Y@5,B?%(P>D;
M2`GQ3(G>3#'63#'F2`.=>/___T@!\T@!RTP!RT&)WTB)QDC![@)(@^`#2,'@
M'D@)\$R)_DC!Y@5,B?E(P>D;2`GQ2(G&3#'>2#'63`-5@$D!\DD!RDT!RD6)
MU$R)\DC!Z@))@^8#2<'F'DD)UDR)XDC!X@5,B>9(P>X;2`G63(GR2#'"2#':
M3`-=B$D!TTD!\TT!RT2)VDR)_DC![@))@^<#2<'G'DD)]TB)UDC!Y@5(B=-(
MP>L;2`GS3(G^3#'V3#'62`-%D$@!\$@!V$P!R$&)PDR)X4C!Z0))@^0#2<'D
M'DD)S$R)T4C!X05,B=9(P>X;2`G.3(GA3#'Y3#'93`-UF$D!SDD!]DT!SD2)
M\TB)UDC![@)(@^(#2,'B'D@)\DB)WDC!Y@5(B=E(P>D;2`GQ2(G63#'F2#'&
M3`-]H$D!]TD!STT!ST6)_4R)T4C!Z0))@^(#2<'B'DD)RDR)Z4C!X05,B>Y(
MP>X;2`G.3(G12#'13#'Q3`-EJ$D!S$D!]$T!S$6)XTB)WDC![@)(@^,#2,'C
M'D@)\TR)WDC!Y@5,B=E(P>D;"<Y$B=$QV40Q^0-5L`'*C8P6UL%BRDR)ZDC!
MZ@))@^4#2<'E'DD)U4B)RDC!X@5(B<Y(P>X;2`G63(GJ2#':3#'B3`-5N$D!
MTDD!\DT!RD6)UDR)WDC![@))@^,#2<'C'DD)\TR)]DC![AM,B?)(@>+___\'
M2,'B!4@)\DR)WDPQ[D@QSD@#7<!(`?-(`=-,`<N)VDB)SDC![@)(@^$#2,'A
M'D@)\4B)UDC!Y@5(P>H;"=9$B=HQRD0QTDR)\$C!X!Y)P>X"20G&1`-%R$4!
MQ4$!U4*-A"[6P6+*2(D'\P]O1PAF20]NSF9(#V[39@]LT68/U-!F#V\%L```
M`&8/V]#S#W]7"/,/;T\89D@/;M%F20]NVV8/;--F#]319@_;T/,/?U<82('$
M"`(``%M!7$%=05Y!7UW#D)"0D)!52(GE4U!(BP532R``2(/X_[OXKV``=!</
M'X0``````/_02(L#2(/#^$B#^/]U\4B#Q`A;7<.0D$B#[`CHW[K__TB#Q`C#
M````````````````,$,``#!%```````````````````P0P```````#!%____
M_P````#_____`````````````,!#```````````N+W!E<FQX<VDN8P``````
M7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("``````````````````
M````4J1```````#OI4````````````````````````````!DI$```````&FD
M0`````````````````!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`979A
M;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[
M(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R
M7W!L.PIM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$
M('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`[
M"G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*
M;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M
M<"D["F]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*
M1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@
M=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD
M("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N
M97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^
M($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@
M)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*<')I;G0@)'1M<"`B(R$O8FEN+W-H
M"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T
M96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*
M<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF
M:6QE;F%M92`N("(G"B(["F-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["FUY
M("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G
M.PIC;&]S92`D=&UP.PIS>7-T96TH)&-M9"D["F]U=',H<7$H4W!A=VYE9"!B
M86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"BX@)'1M
M<"T^9FEL96YA;64I.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"
M3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@
M>PI?<&%R7VEN:71?96YV*"D["FEF("AE>&ES=',@)$5.5GM005)?05)'5E\P
M?2!A;F0@)$5.5GM005)?05)'5E\P?2`I('L*0$%21U8@/2!M87`@)$5.5GLB
M4$%27T%21U9?)%\B?2P@*#$@+BX@)$5.5GM005)?05)'0WT@+2`Q*3L*)#`@
M/2`D14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@>PIF;W(@*&ME>7,@)45.5BD@
M>PID96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O.PI]"GT*;7D@)'%U
M:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S
M97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@
M("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G
M+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/
M4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E=%]P
M87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A
M;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@)'!R
M;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@)'-I
M>F4@/2`M<R`D<')O9VYA;64["FUY("1O9F9S970@/2`U,3(["FUY("1I9'@@
M/2`M,3L*=VAI;&4@*#$I"GL*)&]F9G-E="`]("1S:7IE(&EF("1O9F9S970@
M/B`D<VEZ93L*<V5E:R!?1D@L("TD;V9F<V5T+"`R(&]R(&1I92!Q<5MS965K
M(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=.PIM>2`D;G)E860@/2!R96%D
M(%]&2"P@)&)U9BP@)&]F9G-E=#L*9&EE('%Q6W)E860@9F%I;&5D(&]N("(D
M<')O9VYA;64B.B`D(5T@=6YL97-S("1N<F5A9"`]/2`D;V9F<V5T.PHD:61X
M(#T@<FEN9&5X*"1B=68L(")<;E!!4BYP;5QN(BD["FQA<W0@:68@)&ED>"`^
M/2`P('Q\("1O9F9S970@/3T@)'-I>F4@?'P@)&]F9G-E="`^(#$R."`J(#$P
M,C0["B1O9F9S970@*CT@,CL*?0IL87-T('5N;&5S<R`D:61X(#X](#`["B1O
M9F9S970@+3T@)&ED>"`M(#0["G-E96L@7T9(+"`M)&]F9G-E="P@,CL*<F5A
M9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`M)&]F9G-E="`M('5N<&%C:R@B
M3B(L("1B=68I+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*)&1A=&%?<&]S(#T@
M*'1E;&P@7T9(*2`M(#0["FUY("5R97%U:7)E7VQI<W0["G=H:6QE("@D8G5F
M(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B
M=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO
M=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY("1C
M<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q
M(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH
M/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@
M7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X
M="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("@D
M;W5T+"`D9FEL96YA;64I(#T@7W1E;7!F:6QE*"1E>'0L("1C<F,I.PII9B`H
M)&]U="D@>PIB:6YM;V1E*"1O=70I.PIP<FEN="`D;W5T("1B=68["F-L;W-E
M("1O=70["F-H;6]D(#`W-34L("1F:6QE;F%M93L*?0HD4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H
M("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`]("(D14Y6>U!!4E]414U0?2\D
M8F%S96YA;64D97AT(CL*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["F]P
M96X@;7D@)&]U="P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PIB:6YM;V1E
M*"1O=70I.PIP<FEN="`D;W5T("1B=68["F-L;W-E("1O=70["GT*96QS92![
M"B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1005(Z.DAE879Y.CI-;V1U
M;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C
M<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PI]"G)E860@7T9(+"`D8G5F+"`T
M.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]
M($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1F
M:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O
M('L*;7D@)&ME>3L*9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2!["FYE
M>'0@=6YL97-S("]<421M;V1U;&5<120O.PHD:V5Y(#T@)%\[(&QA<W0["GT*
M9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*
M?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL96YA
M;64O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H
M)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP
M9FEL92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H("1F:6QE
M;F%M92T^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE
M;'-E('L*;7D@*"1O=70L("1N86UE*2`](%]T96UP9FEL92@G+G!M)RP@)&9I
M;&5N86UE+3Y[8W)C?2D["FEF("@D;W5T*2!["F)I;FUO9&4H)&]U="D["G!R
M:6YT("1O=70@)&9I;&5N86UE+3Y[8G5F?3L*8VQO<V4@)&]U=#L*?0IO<&5N
M(&UY("1F:"P@)SPG+"`D;F%M92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*
M<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN
M;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D
M97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*
M<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y
M;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE
M;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S
M("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2![
M"FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE
M;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@
M/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?
M;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P
M,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*;7D@0'!A
M<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M
M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2
M155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N
M;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%2
M1U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES
M=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU
M("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(*
M*3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI
M9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*
M?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I
M;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q
M<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@
M0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B
M=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A
M<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE
M;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@
M*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q
M("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E
M;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L
M;V<Z("0A(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@
M)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD
M,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E
M<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S
M<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*
M97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H
M)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ
M6FEP.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD
M969I;F5D("1P87(I('L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H,3(X
M*C$P,C0I.PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T
M(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G
M24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M
M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII
M<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*
M?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP
M+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD
M+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ
M72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE
M9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A
M<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE
M(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H
M)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL
M93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL
M93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I
M.PHD+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD
M968["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^
M.PII9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_
M.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`[
M"E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@
M)#`I"GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D
M=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF
M("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@
M=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@
M+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N
M("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]
M96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E9CL*:68@*"1B
M=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI
M=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I
M.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L
M92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI
M8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D[
M"GT@0$E.0SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A
M9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?
M97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*
M9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE
M*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*
M96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L
M("1N86UE*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R
M+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE
M879Y.CI-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E
M9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE
M+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@
M=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK
M*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB
M7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D
M9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@
M)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M
M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE
M(")#86XG="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT
M96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%2
M7U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI0
M05(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N
M="P@)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE
M(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L
M(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P
M.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL
M("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E
M;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54
M;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T
M<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY
M("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@979A;"![
M(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\
M?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^
M;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ
M340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z
M.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N
M,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL
M92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD
M(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M
M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N86UE(#T@
M)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M
M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE
M7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F
M:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R
M*2DI.PHD9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H
M;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D
M("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z
M.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H
M:79E.CI::7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF
M9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP
M+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI
M=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ
M3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D
M>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6
M>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@
M)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I
M;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE
M>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]
M("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@
M/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO
M*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*
M?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I
M;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA
M;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N
M8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R
M7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE
M(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M
M92(@=&\@(B1D97-T7VYA;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.
M86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@
M)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE
M>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E
M.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S
M<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I
M;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@
M/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D
M;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E
M;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S
M92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z
M.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A
M=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E
M<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E
M<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@
M=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U
M:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%
M>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR
M97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@
M0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4[
M"G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP
M.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!
M4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I
M<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U
M=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN
M,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R
M97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER
M92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!0
M97)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I
M<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@
M)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@
M>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@
M*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)
M4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT
M('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A
M=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`]
M(&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F
M5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G
M:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@
M/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]
M('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O
M7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A
M<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@
M,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS
M=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O
M9VYA;64I.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U
M9BP@-CL*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L
M(#(["G-Y<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD
M<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*
M96QS92!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@
M1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S
M=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E
M<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*
M:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q
M("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H
M)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD
M<')O9VYA;64B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H
M*3L*8VQO<V4H)&9H*3L*?0I]"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI
M;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE
M("D["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@
M,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%
M3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U
M.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N
M9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92![
M"FUY("@D97AT+"`D8W)C*2`]($!?.PIM>2`H)&9H+"`D9FEL96YA;64I.PHD
M9FEL96YA;64@/2`B)'!A<E]T96UP+R1C<F,D97AT(CL*:68@*"1%3E9[4$%2
M7T-,14%.?2D@>PIU;FQI;FL@)&9I;&5N86UE(&EF("UE("1F:6QE;F%M93L*
M<'5S:"!`=&UP9FEL92P@)&9I;&5N86UE.PI]"F5L<V4@>PIR971U<FX@*'5N
M9&5F+"`D9FEL96YA;64I(&EF("@M<B`D9FEL96YA;64I.PI]"F]P96X@)&9H
M+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<F5T
M=7)N*"1F:"P@)&9I;&5N86UE*3L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF
M("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/
M1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA
M;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G
M;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B
M<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L
M:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X
M*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N
M(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*
M?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M
M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D
M:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]
M*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q
M("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<
M120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G
M;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@
M/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M
M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I
M>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'
M3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@
M/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE
M(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ
M9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z
M.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^
M(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[
M7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS
M=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]
M*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,
M25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)5
M1R!#04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@>PID96QE=&4@)$5.
M5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%
M0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G
M+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D
M<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@
M(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!
M3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@
M>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H
M(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@
M+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@
M)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*
M96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I
M<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF
M:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET
M96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X
M<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.
M0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID
M:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA
M;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M92`D
M<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`
M(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD
M.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z
M.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%
M4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@`O<')O8R\E:2\E<P!0
M05)?5$5-4`!005)?4%)/1TY!344`4$523#5,24(`4$523$Q)0@!015),-4]0
M5`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!
M3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]!4D=#`%!!4E]!4D=67S``4$%2
M7T=,3T)!3%]$14)51P!005)?1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2`%!!
M4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`%!!4E]#3$5!3CT`,0!,
M24)0051(`$193$1?3$E"4D%265]0051(`%-(3$E"7U!!5$@`+W1M<"\`5$5-
M4$1)4@!435``55-%4@!54T523D%-10!P87(M`%-94U1%30`E,#)X`"5S)7,E
M<R5S`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F
M86EL960@*&5R<FYO/25I*0H`)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S
M(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O
M<&5R871I;VXI"@!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M
M)74E<P`E<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P97)L`%5N86)L92!T;R!C
M<F5A=&4@8V%C:&4@9&ER96-T;W)Y`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E
M(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`+64`
M+2T`26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O8W5R<')O8R]F:6QE`"XN
M`"5S+R5S`#H``````1L#.[`````5````Y'?__\P```!D>?__]````#1Z__\4
M`0``9'K__S0!```T>___5`$``$1[__]T`0``A'W__YP!``"D?___Q`$``.1_
M___D`0``M(#__P0"```$C/__+`(``,2,__]4`@``Y(S__W0"``!TCO__G`(`
M`*2;___$`@``-)S__^0"``!DG?__#`,``+2>__\T`P``Q*/__UP#``#DIO__
MA`,``$2G__^D`P``%``````````!>E(``7@0`1L,!PB0`0``)````!P````0
M=___=@$```!!#A"&`D,-!DJ#!XP&C06.!(\#`````!P```!$````:'C__U,`
M````00X0A@)##09"@P,`````'````&0````8>?__)P````!!#A"&`D,-!@``
M```````<````A````"AY___)`````$$.$(8"0PT&3(,%C@2/`QP```"D````
MV'G__PH`````00X0A@)##08`````````)````,0```#(>?__.@(```!!#A"&
M`D,-!E"#!XP&C06.!(\#`````"0```#L````X'O__R`"````00X0A@)##09-
M@P>,!HT%C@2/`P`````<````%`$``-A]__\V`````$$.$(8"0PT&````````
M`!P````T`0``^'W__\D`````00X0A@)##09#@P2.`P``)````%0!``"H?O__
M3PL```!!#A"&`D,-!DV#!XP&C06.!(\#`````"0```!\`0``T(G__[D`````
M00X0A@)##09'@P:,!8X$CP,````````<````I`$``&B*__\?`````$$.$(8"
M0PT&`````````"0```#$`0``:(K__XP!````00X0A@)##09-@P>,!HT%C@2/
M`P`````D````[`$``-"+__\M#0```$$.$(8"0PT&4(,'C`:-!8X$CP,`````
M'````!0"``#8F/__A0````!!#A"&`D,-!D*#`P`````D````-`(``$B9__\I
M`0```$$.$(8"0PT&2H,'C`:-!8X$CP,`````)````%P"``!0FO__1P$```!!
M#A"&`D,-!DV#!XP&C06.!(\#`````"0```"$`@``>)O__P\%````00X0A@)#
M#090@P>,!HT%C@2/`P`````D````K`(``&"@__\7`P```$$.$(8"0PT&38,'
MC`:-!8X$CP,`````'````-0"``!8H___70````!!#A"&`D,-!@`````````D
M````]`(``)BC__];%P```$$.$(8"0PT&4(,'C`:-!8X$CP,`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````#__________P``````````__________\`````````````
M`````````0`````````!``````````$`````````1``````````!````````
M`,4!`````````0````````#/`0````````$`````````W0$````````!````
M`````.H!````````#P`````````R`P```````!T`````````,@,````````,
M`````````,@90```````#0````````#89$````````0`````````2`)`````
M``#U_O]O`````,@$0```````!0`````````X#D````````8`````````L`5`
M```````*`````````#H$````````"P`````````8`````````!4`````````
M```````````#`````````#BR8````````@````````#H!0```````!0`````
M````!P`````````7`````````.`30```````!P````````!H$T````````@`
M````````>``````````)`````````!@`````````_O__;P`````H$T``````
M`/___V\``````@````````#P__]O`````'(20```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````*+!@````
M````````````````````````\AE````````"&D```````!(:0```````(AI`
M```````R&D```````$(:0```````4AI```````!B&D```````'(:0```````
M@AI```````"2&D```````*(:0```````LAI```````#"&D```````-(:0```
M````XAI```````#R&D````````(;0```````$AM````````B&T```````#(;
M0```````0AM```````!2&T```````&(;0```````<AM```````""&T``````
M`)(;0```````HAM```````"R&T```````,(;0```````TAM```````#B&T``
M`````/(;0````````AQ````````2'$```````"(<0```````,AQ```````!"
M'$```````%(<0```````8AQ```````!R'$```````((<0```````DAQ`````
M``"B'$```````+(<0```````PAQ```````#2'$```````.(<0```````\AQ`
M```````"'4```````!(=0```````(AU````````R'4```````$(=0```````
M4AU```````!B'4```````'(=0```````@AU```````"2'4```````*(=0```
M````LAU```````#"'4```````-(=0```````OZ5``````````````````!BP
M8`````````````````#$94```````/____\D1G)E94)31#H@<F5L96YG+S$P
M+C,O;&EB+V-S=2]A;60V-"]C<G0Q+F,@,C0U,3,S(#(P,3,M,#$M,#<@,3<Z
M-3@Z,C=:(&MI8B`D`"1&<F5E0E-$.B!R96QE;F<O,3`N,R]L:6(O8W-U+V-O
M;6UO;B]C<G1B<F%N9"YC(#(Y-S(V,2`R,#$V+3`S+3(U(#`P.C4X.C$U6B!M
M87)I=7,@)``D1G)E94)31#H@<F5L96YG+S$P+C,O;&EB+V-S=2]C;VUM;VXO
M:6=N;W)E7VEN:70N8R`R-#4Q,S,@,C`Q,RTP,2TP-R`Q-SHU.#HR-UH@:VEB
M("0`1G)E94)31"!C;&%N9R!V97)S:6]N(#,N-"XQ("AT86=S+U)%3$5!4T5?
M,S0O9&]T,2UF:6YA;"`R,#@P,S(I(#(P,30P-3$R`"1&<F5E0E-$.B!R96QE
M;F<O,3`N,R]L:6(O8W-U+V%M9#8T+V-R=&DN4R`R,3<Q,#4@,C`Q,2TP,2TP
M-R`Q-CHP-SHU,5H@:VEB("0`)$9R965"4T0Z(')E;&5N9R\Q,"XS+VQI8B]C
M<W4O86UD-C0O8W)T;BY3(#(Q-S$P-2`R,#$Q+3`Q+3`W(#$V.C`W.C4Q6B!K
M:6(@)```+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N=&%G`"YG;G4N:&%S:``N
M9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR
M96QA+F1Y;@`N<F5L82YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N
M96A?9G)A;65?:&1R`"YE:%]F<F%M90`N8W1O<G,`+F1T;W)S`"YJ8W(`+F1Y
M;F%M:6,`+F=O="YP;'0`+F1A=&$`+F)S<P`N8V]M;65N=```````````````
M````````````````````````````````````````````````````````````
M````````````"P````$````"```````````"0`````````(````````5````
M`````````````````0```````````````````!,````'`````@`````````8
M`D```````!@"````````,`````````````````````0`````````````````
M```A````!0````(`````````2`)```````!(`@```````(`"````````!0``
M```````(``````````0`````````'0```/;__V\"`````````,@$0```````
MR`0```````#H``````````4`````````"````````````````````"<````+
M`````@````````"P!4```````+`%````````B`@````````&`````0````@`
M````````&``````````O`````P````(`````````.`Y````````X#@``````
M`#H$```````````````````!````````````````````-P```/___V\"````
M`````'(20```````<A(```````"V``````````4``````````@`````````"
M`````````$0```#^__]O`@`````````H$T```````"@3````````0```````
M```&`````@````@```````````````````!3````!`````(`````````:!-`
M``````!H$P```````'@`````````!0`````````(`````````!@`````````
M70````0````"`````````.`30```````X!,```````#H!0````````4````,
M````"``````````8`````````&<````!````!@````````#(&4```````,@9
M````````$P````````````````````0```````````````````!B`````0``
M``8`````````W!E```````#<&0`````````$```````````````````$````
M`````!``````````;0````$````&`````````.`=0```````X!T```````#X
M1@``````````````````$````````````````````',````!````!@``````
M``#89$```````-AD````````#@````````````````````0`````````````
M``````!Y`````0````(`````````\&1```````#P9`````````E!````````
M```````````0````````````````````@0````$````"`````````/RE0```
M````_*4```````"T````````````````````!````````````````````(\`
M```!`````@````````"PID```````+"F````````'`,`````````````````
M``@```````````````````"9`````0````,``````````+!@````````L```
M`````!`````````````````````(````````````````````H`````$````#
M`````````!"P8```````$+`````````0````````````````````"```````
M`````````````*<````!`````P`````````@L&```````""P````````"```
M``````````````````@```````````````````"L````!@````,`````````
M*+!@```````HL````````!`"````````!@`````````(`````````!``````
M````M0````$````#`````````#BR8```````.+(````````0`@``````````
M````````"``````````(`````````+X````!`````P````````!(M&``````
M`$BT````````+`````````````````````@```````````````````#$````
M"`````,`````````@+1@``````!TM````````*@$```````````````````0
M````````````````````R0````$````P````````````````````=+0`````
M``#:`0```````````````````0`````````!``````````$````#````````
M`````````````````$ZV````````T@````````````````````$`````````
(````````````
